@@ -1,19 +1,36 @@
-# $Id: lowess.R,v 1.5 2002/09/23 13:59:30 warnes Exp $
+# $Id: lowess.R,v 1.6 2003/01/02 16:07:35 warnes Exp $
 #
 # $Log: lowess.R,v $
+# Revision 1.6  2003/01/02 16:07:35  warnes
+#
+# - Added wrapper code so that R-specific fiddling won't be executed
+#   under S-Plus.
+#
 # Revision 1.5  2002/09/23 13:59:30  warnes
 # - Modified all files to include CVS Id and Log tags.
 #
 #
 
-lowess  <- function(x,...)
-  UseMethod("lowess")
+if(is.R())
+  {
+    # make original lowess into the default method
+    lowess.default  <- get("lowess",pos=NULL, mode="function")
 
-# make original lowess into the default method
-lowess.default  <- get("lowess",pos=NULL, mode="function")
+    lowess  <- function(x,...)
+      UseMethod("lowess")
+
+    # add "..." to the argument list to match the generic
+    formals(lowess.default) <- c(formals(lowess.default),alist(...= ))
+  } else
+  {
+
+    # make original lowess into the default method
+    lowess.default  <- get("lowess", mode="function")
+
+    lowess  <- function(x,...)
+      UseMethod("lowess")
+  }
 
-# add "..." to the argument list to match the generic
-formals(lowess.default) <- c(formals(lowess.default),alist(...= ))
 
 
 "lowess.formula" <-  function (formula,
